@@ -1,3 +1,4 @@
+use crate::general::Approach;
 use crate::general::c_string_to_option_string;
 use crate::general::c_string_to_string;
 use crate::general::CGeneralOptions;
@@ -229,6 +230,11 @@ impl MatchRequest {
         }
     }
 
+    pub fn approach(&mut self, approaches: Option<Vec<Option<Approach>>>) -> &mut MatchRequest {
+        self.general_options.approach = approaches;
+        self
+    }
+
     pub fn exclude(&mut self, exclude: Option<Vec<String>>) -> &mut MatchRequest {
         self.general_options.exclude(&exclude);
         self
