@@ -1,3 +1,4 @@
+use crate::general::Approach;
 use crate::general::Coordinate;
 use crate::general::Waypoint;
 use crate::general::{CGeneralOptions, CWaypoint, GeneralOptions};
@@ -227,6 +228,11 @@ impl TableRequest {
         }
     }
 
+    pub fn approach(&mut self, approaches: Option<Vec<Option<Approach>>>) -> &mut TableRequest {
+        self.general_options.approach = approaches;
+        self
+    }
+
     pub fn exclude(&mut self, exclude: Option<Vec<String>>) -> &mut TableRequest {
         self.general_options.exclude(&exclude);
         self
